from gwlogging import logger
from GwErrors import GwError

from datetime import datetime

class GeophoneDataLine:
    l_id = None
    x = None
    y = None
    z = None

    def __init__(self, l_id, x, y, z):
        self.l_id = l_id
        self.x = x
        self.y = y
        self.z = z

    def __str__(self):
        return "%s\t%s\t%s\t%s\r\n" % (self.l_id, self.x, self.y, self.x)


class GeophoneDataFile:
    filename = None
    size = None
    sample_ptr = None
    rtc_current = None
    rtc_ref = None
    rtc = None
    missed = None
    data = []

    def __init__(self, filename, size, sample_ptr, rtc_current, rtc_ref,
            rtc, missed):
        self.filename = filename
        self.size = int(size)
        self.sample_ptr = int(sample_ptr)
        self.rtc_current = int(rtc_current)
        self.rtc_ref = int(rtc_ref)
        self.rtc = datetime.utcfromtimestamp(float(rtc))
        self.missed = int(missed)

    def add_line(self, line):
        self.data.append(line)

    def __str__(self):
        ret = "Filename: %s RTC: %s SamplePtr: %s\r\n" % (self.filename, self.rtc,
            self.sample_ptr)
        for l in self.data:
            ret += str(l)
        return ret


def parse(data_file):
    try:
        f = open(data_file, "r")
        lines = f.readlines()
        f.close()
    except IOError:
        logger.critical("Unable to open file")
        raise GwError()
    arr = lines[0].split(" ")
    filename = arr[1].split(":")[1]
    size = int(arr[3])
    arr = lines[1].split(",")
    sample_ptr = arr[0].split(" ")[1]
    rtc_current = arr[1].split(" ")[2]
    rtc_ref = arr[2].split(" ")[2]
    rtc = arr[3].split(" ")[2]
    missed = arr[4].split(" ")[2]
    geo_data = GeophoneDataFile(filename, size, sample_ptr, rtc_current,
            rtc_ref, rtc, missed)
    for line in lines[3:]:
        arr = line.split("\t")
        geo_data.add_line(GeophoneDataLine(int(arr[0]), int(arr[1]),
            int(arr[2]), int(arr[3])))
    return geo_data
