from gwlogging import logger
from datetime import datetime
from gwtimeutils import totimestamp


def parse(line):
    arr = line.split("\t")
    return Gw12InstantSense(datetime.utcfromtimestamp(float(arr[0])),
        int(arr[1]), int(arr[2]), float(arr[3]), int(arr[4]), int(arr[5]),
        float(arr[6]), int(arr[7]), int(arr[8]), int(arr[9]), int(arr[10]),
        int(arr[11]), int(arr[12]), int(arr[13]), int(arr[14]), int(arr[15]),
        int(arr[16]), int(arr[17]), int(arr[18]))


def parse_raw(line):
    logger.warn("This is a Jeffified method - yuck")
    arr = line.split("\t")
    return Gw12InstantSense(int(arr[0]), int(arr[1]),
        int(arr[2]), float(arr[3]), int(arr[4]), int(arr[5]), float(arr[6]),
        int(arr[7]), int(arr[8]), int(arr[9]), int(arr[10]), int(arr[11]),
        int(arr[12]), int(arr[13]), int(arr[14]), int(arr[15]), int(arr[16]),
        int(arr[17]), int(arr[18]))


class Gw12InstantSense:

    def __init__(self, rtc, rtc_counter, batt_volts, vdd, temp_platinum,
            temp_internal, temp_internal_celcius, pressure, strain,
            conductivity, accelerometer_x, accelerometer_y, accelerometer_z,
            compass_x, compass_y, compass_z, gyro_x, gyro_y, gyro_z):
        self.rtc = rtc
        self.rtc_counter = rtc_counter
        self.batt_volts = batt_volts
        self.vdd = vdd
        self.temp_platinum = temp_platinum
        self.temp_internal = temp_internal
        self.temp_internal_celcius = temp_internal_celcius
        self.pressure = pressure
        self.strain = strain
        self.conductivity = conductivity
        self.accelerometer_x = accelerometer_x
        self.accelerometer_y = accelerometer_y
        self.accelerometer_z = accelerometer_z
        self.compass_x = compass_x
        self.compass_y = compass_y
        self.compass_z = compass_z
        self.gyro_x = gyro_x
        self.gyro_y = gyro_y
        self.gyro_z = gyro_z

    def __str__(self):
        ret = str(self.rtc) + " " + str(self.rtc_counter) + "\n" +\
            "Batt Volts Raw: " + str(self.batt_volts) + "\n" +\
            "VDD: " + str(self.vdd) + "\n" +\
            "Temperature Platinum: " + str(self.temp_platinum) + "\n" +\
            "Internal Temperature Raw:" + str(self.temp_internal) +\
            " Converted: " + "\nPressure: " + str(self.pressure) + "\n" +\
            "Strain: " + str(self.strain) + "\n" +\
            "Accelerometer X:" + str(self.accelerometer_x) + " Y:" +\
            str(self.accelerometer_y) + " Z:" + str(self.accelerometer_z) +\
            "\n" + "Compass X:" + str(self.compass_x) + " Y:" +\
            str(self.compass_y) + " Z:" + str(self.compass_z) + "\n" +\
            "Gyro X:" + str(self.gyro_x) + " Y:" + str(self.gyro_y) + " Z:" +\
            str(self.gyro_z)
        return ret

    def compact_string(self):
        ret = "%-10d %-10d %-7d %-5.3f %-6d %-6d %-6.2f %-6d %-6d %-6d %-6d" +\
            " %-6d %-6d %-6d %-6d %-6d %-6d %-6d %-6d" % (
            totimestamp(self.rtc), self.rtc_counter, self.batt_volts, self.vdd,
            self.temp_platinum, self.temp_internal, self.temp_internal_celcius,
            self.pressure, self.strain, self.conductivity,
            self.accelerometer_x, self.accelerometer_y, self.accelerometer_z,
            self.compass_x, self.compass_y, self.compass_z, self.gyro_x,
            self.gyro_y, self.gyro_z)
        return ret

    def __repr__(self):
        ret = "%s %d %d %f %d %d %f %d %d %d %d %d %d %d %d %d %d %d %d\r\n"\
            % (self.rtc, self.rtc_counter, self.batt_volts, self.vdd,
            self.temp_platinum, self.temp_internal, self.temp_internal_celcius,
            self.pressure, self.strain, self.conductivity,
            self.accelerometer_x, self.accelerometer_y, self.accelerometer_z,
            self.compass_x, self.compass_y, self.compass_z, self.gyro_x,
            self.gyro_y, self.gyro_z)
        return ret
