#!/usr/bin/env python
from gwlogging import logger
import GeophoneData
import GeophoneDygraph

from bottle import route, run, static_file
from optparse import OptionParser
from os import listdir

DEFAULT_STATIC_ROOT = "/home/pjb08r/glacsweb/probe/gw12/linux/trunk/www/"
DEFAULT_DATA_ROOT = "/glacsweb/data"
DEFAULT_LISTEN_ADDRESS = "0.0.0.0"
DEFAULT_PORT = 9090

STATIC_ROOT = None
DATA_ROOT = None
LISTEN_ADDRESS = None
PORT = None

@route("/dygraph-combined.js")
def send_dygraph_lib():
    logger.debug("Serving dygraph library")
    return static_file("dygraph-combined.js", root=STATIC_ROOT,
        mimetype="text/javascript")

@route("/")
@route("/help")
def help():
    return """
    <html><body><h1>Geophone data plotter</h1>
    <a href="list"> List the available data files</a><br/>
    </body></html>
    """

@route("/list")
def list():
    ret = "<html><body><h1>File Listing</h1><ul>\n"
    files = listdir(DATA_ROOT)
    for f in files:
        ret += '<li><a href="/graph/%s">%s/></li>\n' % (f, f)
    ret+= "</ul></body></html>"
    return ret


@route("/graph/<f>")
def graph(f):
    ret = """<html>
    <head>
    <script type="text/javascript"
      src="/dygraph-combined.js"></script>
    </head>
    <body>
    <div id="graphdiv"></div>
    <script type = "text/javascript">
    """
    filename = DATA_ROOT +"/" +  f
    print filename
    d = GeophoneData.parse(filename)
    ret += GeophoneDygraph.convert(d)
    ret += """ </script></body></html>"""
    return ret

if __name__ == "__main__":
    parser = OptionParser()
    parser.add_option("-p", "--port", type="int", dest="port",
        help="Port to use for webserver")
    parser.add_option("-l", "--listen", type="string", dest="listen",
        help="Address for the server to listen on")
    parser.add_option("-d", "--data", type="string", dest="data_path",
        help="Path for data folder")
    parser.add_option("-s", "--static", type="string", dest = "static_path",
        help="Path from which to serve static files")
    (options, args) = parser.parse_args()

    if options.port is not None:
        PORT = options.port
    else:
        PORT = DEFAULT_PORT
    logger.debug("Using port %d" % PORT)
    
    if options.listen is not None:
        LISTEN_ADDRESS = options.listen
    else:
        LISTEN_ADDRESS = DEFAULT_LISTEN_ADDRESS
    logger.debug("Listening on %s" % LISTEN_ADDRESS)

    if options.data_path is not None:
        DATA_ROOT = options.data_path
    else:
        DATA_ROOT = DEFAULT_DATA_ROOT
    logger.debug("Using %s as data root" % DATA_ROOT)

    if options.static_path is not None:
        STATIC_ROOT = options.static_path
    else:
        STATIC_ROOT = DEFAULT_STATIC_ROOT
    logger.debug("Using %s as  static root" % STATIC_ROOT)

    run(host=LISTEN_ADDRESS, port=PORT)
