#!/usr/bin/env python

from gwlogging import logger
from Gw12 import Gw12, SSNS, SSN_GATEWAY
from GwErrors import GwProbeExecutionError
from variables import MAX_PROBE_PING_REPEATS

from random import shuffle

if __name__ == "__main__":
    logger.debug("Trying wired probes")
    probe_interface = Gw12()
    try:
        probe_interface.nodestatus(SSN_GATEWAY)
    except GwProbeExecutionError:
        try:
            logger.warn("Attempt 1 failure pinging SGN")
            probe_interface.nodestatus(SSN_GATEWAY)
        except GwProbeExecutionError:
            logger.critical("Unable to ping gateway = giving up")
            exit(1)

    shuffle(SSNS)
    logger.debug(SSNS)
    logger.debug(" SSNS shuffled")
    i = 0
    try:
        while i < MAX_PROBE_PING_REPEATS:
            for probe in SSNS:
                try:
                    probe_interface.nodestatus(probe)
                    logger.info("Got status from %s" % probe)
                    probe_interface.get_files(probe)
                    logger.info("Finished doing transfers from %s" % probe)
                    probe_interface.nodesleep(probe)
                    logger.info("SSN  %s sent to sleep" % probe)
                    SSNS.remove(probe)
                except GwProbeExecutionError:
                    logger.error("Failed to get comms from %s" % probe)
            if SSNS == []:
                logger.info("All SSNS spoken to")
                break
            i += 1
    except KeyboardInterrupt:
        logger.warn("Halted by keyboard")
    logger.info("Getting data from SGN")
    probe_interface.get_files(SSN_GATEWAY)
    logger.info("Dumped data from SGN")
